==> nocc-1.8.3.tbz: www/nocc/lang/br.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: br.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Breton (Brezhoneg)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Fohanno
 * @author Fulup
 * @author Y-M D
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Goullo eo maezienn an anv implijer';
$err_passwd_empty = 'Goullo eo maezienn ar ger-tremen';
$alt_delete = 'Dilemel ar c\'hemennadennoù diuzet';
$alt_delete_one = 'Diverkañ ar gemennadenn';
$alt_new_msg = 'Posteloù nevez';
$alt_reply = 'Respont d\'an aozer';
$alt_reply_all = 'Respont d\'an holl';
$alt_forward = 'Adkas';
$alt_next = 'War-lerc\'h';
$alt_prev = 'Kent';
$title_next_page = 'Pajenn war-lerc\'h';
$title_prev_page = 'Pajenn gent';
$title_next_msg = 'Postel war-lerc\'h';
$title_prev_msg = 'Postel kent';
$html_theme_label = 'Tem :';
$html_welcome = 'Degemer mat da %1$s';
$html_login = 'Kevreañ';
$html_user_label = 'Implijer :';
$html_passwd_label = 'Ger-tremen :';
$html_submit = 'Kas';
$html_help = 'Skoazell';
$html_server_label = 'Servijer :';
$html_wrong = 'Direizh eo an anv implijer pe ar ger-tremen';
$html_retry = 'Adklask';
$html_remember = 'Derc\'hel soñj eus an arventennoù';
$html_lang_label = 'Yezh :';
$html_msgperpage_label = 'Posteloù dre bajenn :';
$html_preferences = 'Penndibaboù';
$html_full_name_label = 'Anv klok :';
$html_email_address_label = 'Chomlec\'h postel :';
$html_ccself = 'Resev un eilad';
$html_hide_addresses = 'Kuzhat ar chomlec\'hioù';
$html_outlook_quoting = 'Menegoù e doare Outlook';
$html_reply_to = 'Respont da';
$html_use_signature = 'Implijout ar sinadur';
$html_signature = 'Sinadur';
$html_signature_label = 'Sinadur :';
$html_reply_leadin_label = 'Talbenn ar respont :';
$html_prefs_updated = 'Hizivaet eo ar penndibaboù';
$html_manage_folders_link = 'Merañ ar renkelloù IMAP';
$html_manage_filters_link = 'Merañ ar siloù posteloù';
$html_use_graphical_smilies = 'Implijout fromlunioù grafek';
$html_sent_folder_label = 'Eilañ ar posteloù kaset en ur renkell a-ratozh :';
$html_trash_folder_label = 'Dilec\'hiañ ar posteloù dilamet d\'ur renkell a-ratozh :';
$html_colored_quotes = 'Menegoù e liv';
$html_display_struct = 'Diskwel an destenn frammet';
$html_send_html_mail = 'Kas ar postel er furmad HTML';
$html_folders = 'Renkelloù';
$html_folders_create_failed = 'N\'eus ket bet gallet krouiñ ar renkell !';
$html_folders_sub_failed = 'Ne c\'haller ket koumanantiñ d\'ar renkell !';
$html_folders_unsub_failed = 'Ne c\'haller ket digoumanantiñ diouzh ar renkell !';
$html_folders_rename_failed = 'N\'eus ket bet gallet adenvel ar renkell !';
$html_folders_updated = 'Hizivaet eo ar renkelloù';
$html_folder_subscribe = 'Koumanantiñ da';
$html_folder_rename = 'Adenvel';
$html_folder_create = 'Krouiñ ur renkell nevez anvet';
$html_folder_remove = 'Digoumanantiñ diouzh';
$html_folder_delete = 'Diverkañ';
$html_folder_to = 'da';
$html_filter_remove = 'Diverkañ';
$html_filter_body = 'Korf ar gemennadenn';
$html_filter_subject = 'Danvez ar gemennadenn';
$html_filter_to = 'Maezienn Da';
$html_filter_cc = 'Maezienn Ek';
$html_filter_from = 'Maezienn Digant';
$html_filter_change_tip = 'Evit cheñch ur sil, adskrivit warnañ.';
$html_reapply_filters = 'Adarloañ an holl siloù';
$html_filter_contains = 'zo ennañ';
$html_filter_name = 'Anv ar sil';
$html_filter_action = 'Obererezh ar sil';
$html_filter_moveto = 'Kas da';
$html_select_one = '--Dibab unan--';
$html_and = 'Ha';
$html_new_msg_in = 'Kemennadennoù nevez e-barzh';
$html_or = 'pe';
$html_move = 'Dilec\'hiañ';
$html_copy = 'Eilañ';
$html_messages_to = 'ar c\'hemennadennoù diuzet da';
$html_gotopage = 'Mont d\'ar bajenn';
$html_gotofolder = 'Mont d\'ar renkell';
$html_other_folders = 'Roll ar renkelloù';
$html_page = 'Pajenn';
$html_of = 'eus';
$html_view_header = 'Gwelet an talbenn';
$html_remove_header = 'Kuzhat an talbenn';
$html_inbox = 'Boest degemer';
$html_new_msg = 'Skrivañ';
$html_reply = 'Respont';
$html_reply_short = 'Re :';
$html_reply_all = 'Respont d\'an holl';
$html_forward = 'Adkas';
$html_forward_short = 'Adks';
$html_forward_info = 'Kaset e vo ar gemennadenn treuzkaset evel ur pezh stag ouzh ar gemennadenn-mañ.';
$html_delete = 'Diverkañ';
$html_new = 'Nevez';
$html_mark = 'Diverkañ';
$html_att_label = 'Pezh stag :';
$html_atts_label = 'Pezhioù stag :';
$html_unknown = '[dianav]';
$html_attach = 'Stagañ';
$html_attach_forget = 'Ret eo deoc\'h stagañ ho restr a-raok kas ar gemennadenn !';
$html_attach_delete = 'Lemel ar restroù diuzet';
$html_attach_none = 'Ret eo deoc\'h diuzañ ur restr da stagañ !';
$html_sort_by = 'Urzhiañ dre';
$html_sort = 'Urzhiañ';
$html_from = 'Digant';
$html_from_label = 'Digant :';
$html_subject = 'Danvez';
$html_subject_label = 'Danvez :';
$html_date = 'Deiziad';
$html_date_label = 'Deiziad :';
$html_sent_label = 'Kaset d\'an :';
$html_wrote = 'he/en deus skrivet';
$html_size = 'Ment';
$html_totalsize = 'Ment hollek';
$html_kb = 'ko';
$html_mb = 'Mo';
$html_gb = 'Go';
$html_bytes = 'okted';
$html_filename = 'Restr';
$html_to = 'Da';
$html_to_label = 'Da :';
$html_cc = 'Ek';
$html_cc_label = 'Ek :';
$html_bcc_label = 'Ekk :';
$html_nosubject = 'Titl ebet';
$html_send = 'Kas';
$html_cancel = 'Nullañ';
$html_no_mail = 'Postel ebet.';
$html_logout = 'Digevreañ';
$html_msg = 'Postel';
$html_msgs = 'Posteloù';
$html_configuration = 'Ar servijer-mañ n\'eo ket kevreet evel zo dleet !';
$html_priority = 'Kentwir :';
$html_priority_label = 'Kentwir :';
$html_lowest = 'izelañ';
$html_low = 'Izel';
$html_normal = 'Ordinal';
$html_high = 'Uhel';
$html_highest = 'Uhelañ';
$html_flagged = 'Merket';
$html_spam = 'Strob';
$html_spam_warning = 'Merket eo bet ar gemmadenn-mañ evel ur strob.';
$html_receipt = 'Goulenn un testeni resev';
$html_select = 'Diuzañ';
$html_select_all = 'Eilpennañ an diuzadenn';
$html_select_contacts = 'Diuzañ an darempredoù';
$html_loading_image = 'O kargañ ar skeudenn';
$html_send_confirmed = 'Kaset eo bet ho postel';
$html_no_sendaction = 'N\'eus bet diferet ober ebet. Klaskit gweredekaat JavaScript.';
$html_error_occurred = 'C\'hoarvezet ez eus ur fazi';
$html_prefs_file_error = 'Ne c\'haller ket digeriñ restr ar penndibaboù evit skrivañ.';
$html_wrap = 'Treujañ ar c\'hemennadennoù a ya kuit da :';
$html_wrap_none = 'Treujadur ebet';
$html_usenet_separator = 'Disranner Usenet ("-- \n") a-raok ar sinadur';
$html_mark_as = 'Merkañ evel';
$html_read = 'lennet';
$html_unread = 'anlennet';
$html_encoding_label = 'Kodadur an destenn :';
$html_add = 'Ouzhpennañ';
$html_contacts = 'Darempredoù %1$s';
$html_modify = 'Kemmañ';
$html_back = 'Distreiñ';
$html_contact_add = 'Ouzhpennañ un darempred nevez';
$html_contact_mod = 'Kemmañ un darempred';
$html_contact_first = 'Anv-bihan';
$html_contact_last = 'Anv';
$html_contact_nick = 'Lesanv';
$html_contact_mail = 'Postel';
$html_contact_list = 'Roll darempredoù %1$s';
$html_contact_del = 'eus ar roll darempredoù';
$html_contact_count = '%1$d darempred';
$html_contact_err1 = 'An niver uhelañ a zarempredoù zo « %1$d »';
$html_contact_err2 = 'Ne c\'hallit ket ouzhpennañ un darempred nevez';
$html_contact_err3 = 'N\'hoc\'h eus ket gwir da vont d\'ar roll darempredoù';
$html_contact_none = 'N\'eus bet kavet darempred ebet';
$html_del_msg = 'Dilemel ar c\'hemennadennoù diuzet ?';
$html_down_mail = 'Pellgargañ';
$original_msg = '-- Kemennadenn orin --';
$to_empty = 'Ar vaezienn "Da" ne rank ket bezañ goullo !';
$html_images_warning = 'Evit ho surentez ne vez ket diskwelet ar skeudennoù a-bell.';
$html_images_display = 'Diskwel ar skeudennoù';
$html_smtp_error_no_conn = 'Ne c\'haller ket digeriñ ar c\'hevreadur SMTP';
$html_smtp_error_unexpected = 'Respont SMTP dic\'hortoz :';
$lang_could_not_connect = 'N\'eus ket bet gallet kevreañ ouzh ar servijer';
$lang_invalid_msg_num = 'Direizh eo niverenn ar gemennadenn';
$html_file_upload_attack = 'Un dagadenn a c\'hall bezañ diwar ar restr karget';
$html_invalid_email_address = 'Chomlec\'h postel direizh';
$html_invalid_msg_per_page = 'Direizh eo an niver a gemennadennoù dre bajenn';
$html_invalid_wrap_msg = 'Direizh eo ledander treujadur ar gemennadenn';
$html_seperate_msg_win = 'Kemennadennoù e prestroù disrann';
$html_err_file_contacts = 'Ne c\'haller ket digeriñ restr an darempredoù evit skrivañ.';
$html_session_file_error = 'Ne c\'haller ket digeriñ restr an dalc\'hoù evit skrivañ.';
$html_login_not_allowed = 'N\'eo ket aotreet kevreañ gant an anv implijer-mañ.';
$lang_err_send_delay = 'Ret eo deoc\'h gortoz etre daou bostel (%1$d eilenn)';
$html_search = 'Klask';

==> nocc-1.9.1.tbz: www/nocc/lang/br.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: br.php 2400 2011-02-24 10:59:24Z siebrand $
 */
/** Breton (Brezhoneg)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Fohanno
 * @author Fulup
 * @author Y-M D
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Goullo eo maezienn an anv implijer';
$err_passwd_empty = 'Goullo eo maezienn ar ger-tremen';
$alt_delete = 'Dilemel ar c\'hemennadennoù diuzet';
$alt_delete_one = 'Diverkañ ar gemennadenn';
$alt_new_msg = 'Posteloù nevez';
$alt_reply = 'Respont d\'an aozer';
$alt_reply_all = 'Respont d\'an holl';
$alt_forward = 'Adkas';
$alt_next = 'War-lerc\'h';
$alt_prev = 'Kent';
$title_next_page = 'Pajenn war-lerc\'h';
$title_prev_page = 'Pajenn gent';
$title_next_msg = 'Postel war-lerc\'h';
$title_prev_msg = 'Postel kent';
$html_theme_label = 'Tem :';
$html_welcome = 'Degemer mat da %1$s';
$html_login = 'Kevreañ';
$html_user_label = 'Implijer :';
$html_passwd_label = 'Ger-tremen :';
$html_submit = 'Kas';
$html_help = 'Skoazell';
$html_server_label = 'Servijer :';
$html_wrong = 'Direizh eo an anv implijer pe ar ger-tremen';
$html_retry = 'Adklask';
$html_remember = 'Derc\'hel soñj eus an arventennoù';
$html_lang_label = 'Yezh :';
$html_msgperpage_label = 'Posteloù dre bajenn :';
$html_preferences = 'Penndibaboù';
$html_full_name_label = 'Anv klok :';
$html_email_address_label = 'Chomlec\'h postel :';
$html_bccself = 'Ekk ma-unan';
$html_hide_addresses = 'Kuzhat ar chomlec\'hioù';
$html_outlook_quoting = 'Menegoù e doare Outlook';
$html_reply_to = 'Respont da';
$html_use_signature = 'Implijout ar sinadur';
$html_signature = 'Sinadur';
$html_signature_label = 'Sinadur :';
$html_reply_leadin_label = 'Talbenn ar respont :';
$html_prefs_updated = 'Hizivaet eo ar penndibaboù';
$html_manage_folders_link = 'Merañ ar renkelloù IMAP';
$html_manage_filters_link = 'Merañ ar siloù posteloù';
$html_use_graphical_smilies = 'Implijout fromlunioù grafek';
$html_sent_folder_label = 'Eilañ ar posteloù kaset en ur renkell a-ratozh :';
$html_trash_folder_label = 'Dilec\'hiañ ar posteloù dilamet d\'ur renkell a-ratozh :';
$html_colored_quotes = 'Menegoù e liv';
$html_display_struct = 'Diskwel an destenn frammet';
$html_send_html_mail = 'Kas ar postel er furmad HTML';
$html_folders = 'Renkelloù';
$html_folders_create_failed = 'N\'eus ket bet gallet krouiñ ar renkell !';
$html_folders_sub_failed = 'Ne c\'haller ket koumanantiñ d\'ar renkell !';
$html_folders_unsub_failed = 'Ne c\'haller ket digoumanantiñ diouzh ar renkell !';
$html_folders_rename_failed = 'N\'eus ket bet gallet adenvel ar renkell !';
$html_folders_updated = 'Hizivaet eo ar renkelloù';
$html_folder_subscribe = 'Koumanantiñ da';
$html_folder_rename = 'Adenvel';
$html_folder_create = 'Krouiñ ur renkell nevez anvet';
$html_folder_remove = 'Digoumanantiñ diouzh';
$html_folder_delete = 'Diverkañ';
$html_folder_to = 'da';
$html_filter_remove = 'Diverkañ';
$html_filter_body = 'Korf ar gemennadenn';
$html_filter_subject = 'Danvez ar gemennadenn';
$html_filter_to = 'Maezienn Da';
$html_filter_cc = 'Maezienn Ek';
$html_filter_from = 'Maezienn Digant';
$html_filter_change_tip = 'Evit cheñch ur sil, adskrivit warnañ.';
$html_reapply_filters = 'Adarloañ an holl siloù';
$html_filter_contains = 'zo ennañ';
$html_filter_name = 'Anv ar sil';
$html_filter_action = 'Obererezh ar sil';
$html_filter_moveto = 'Kas da';
$html_select_one = '--Dibab unan--';
$html_and = 'Ha';
$html_new_msg_in = 'Kemennadennoù nevez e-barzh';
$html_or = 'pe';
$html_move = 'Dilec\'hiañ';
$html_copy = 'Eilañ';
$html_messages_to = 'ar c\'hemennadennoù diuzet da';
$html_gotopage = 'Mont d\'ar bajenn';
$html_gotofolder = 'Mont d\'ar renkell';
$html_other_folders = 'Roll ar renkelloù';
$html_page = 'Pajenn';
$html_of = 'eus';
$html_view_header = 'Gwelet an talbenn';
$html_remove_header = 'Kuzhat an talbenn';
$html_inbox = 'Boest resev';
$html_new_msg = 'Skrivañ';
$html_reply = 'Respont';
$html_reply_short = 'Re :';
$html_reply_all = 'Respont d\'an holl';
$html_forward = 'Adkas';
$html_forward_short = 'Adks';
$html_forward_info = 'Kaset e vo ar gemennadenn treuzkaset evel ur pezh stag ouzh ar gemennadenn-mañ.';
$html_delete = 'Diverkañ';
$html_new = 'Nevez';
$html_mark = 'Diverkañ';
$html_att_label = 'Pezh stag :';
$html_atts_label = 'Pezhioù stag :';
$html_unknown = '[dianav]';
$html_part_x = 'Lodenn %s';
$html_attach = 'Stagañ';
$html_attach_forget = 'Ret eo deoc\'h stagañ ho restr a-raok kas ar gemennadenn !';
$html_attach_delete = 'Lemel ar restroù diuzet';
$html_attach_none = 'Ret eo deoc\'h diuzañ ur restr da stagañ !';
$html_sort_by = 'Urzhiañ dre';
$html_sort = 'Urzhiañ';
$html_from = 'Digant';
$html_from_label = 'Digant :';
$html_subject = 'Danvez';
$html_subject_label = 'Danvez :';
$html_date = 'Deiziad';
$html_date_label = 'Deiziad :';
$html_sent_label = 'Kaset d\'an :';
$html_wrote = 'he/en deus skrivet';
$html_size = 'Ment';
$html_totalsize = 'Ment hollek';
$html_kb = 'ko';
$html_mb = 'Mo';
$html_gb = 'Go';
$html_bytes = 'okted';
$html_filename = 'Restr';
$html_to = 'Da';
$html_to_label = 'Da :';
$html_cc = 'Ek';
$html_cc_label = 'Ek :';
$html_bcc_label = 'Ekk :';
$html_nosubject = 'Titl ebet';
$html_send = 'Kas';
$html_cancel = 'Nullañ';
$html_no_mail = 'Postel ebet.';
$html_logout = 'Digevreañ';
$html_msg = 'Postel';
$html_msgs = 'Posteloù';
$html_configuration = 'Ar servijer-mañ n\'eo ket kevreet evel zo dleet !';
$html_priority = 'Kentwir :';
$html_priority_label = 'Kentwir :';
$html_lowest = 'izelañ';
$html_low = 'Izel';
$html_normal = 'Ordinal';
$html_high = 'Uhel';
$html_highest = 'Uhelañ';
$html_flagged = 'Merket';
$html_spam = 'Strob';
$html_spam_warning = 'Merket eo bet ar gemmadenn-mañ evel ur strob.';
$html_receipt = 'Goulenn un testeni resev';
$html_select = 'Diuzañ';
$html_select_all = 'Eilpennañ an diuzadenn';
$html_select_contacts = 'Diuzañ an darempredoù';
$html_loading_image = 'O kargañ ar skeudenn';
$html_send_confirmed = 'Kaset eo bet ho postel';
$html_no_sendaction = 'N\'eus bet diferet ober ebet. Klaskit gweredekaat JavaScript.';
$html_error_occurred = 'C\'hoarvezet ez eus ur fazi';
$html_prefs_file_error = 'Ne c\'haller ket digeriñ restr ar penndibaboù evit skrivañ.';
$html_wrap = 'Treujañ ar c\'hemennadennoù a ya kuit da :';
$html_wrap_none = 'Treujadur ebet';
$html_usenet_separator = 'Disranner Usenet ("-- \n") a-raok ar sinadur';
$html_mark_as = 'Merkañ evel';
$html_read = 'lennet';
$html_unread = 'anlennet';
$html_encoding_label = 'Kodadur an destenn :';
$html_add = 'Ouzhpennañ';
$html_contacts = 'Darempredoù %1$s';
$html_modify = 'Kemmañ';
$html_back = 'Distreiñ';
$html_contact_add = 'Ouzhpennañ un darempred nevez';
$html_contact_mod = 'Kemmañ un darempred';
$html_contact_first = 'Anv-bihan';
$html_contact_last = 'Anv';
$html_contact_nick = 'Lesanv';
$html_contact_mail = 'Postel';
$html_contact_list = 'Roll darempredoù %1$s';
$html_contact_del = 'eus ar roll darempredoù';
$html_contact_count = '%1$d darempred';
$html_contact_err1 = '"%1$d" eo an niver uhelañ a zarempredoù';
$html_contact_err2 = 'Ne c\'hallit ket ouzhpennañ un darempred nevez';
$html_contact_err3 = 'N\'hoc\'h eus ket gwir da vont d\'ar roll darempredoù';
$html_contact_none = 'N\'eus bet kavet darempred ebet';
$html_del_msg = 'Dilemel ar c\'hemennadennoù diuzet ?';
$html_down_mail = 'Pellgargañ';
$original_msg = '-- Kemennadenn orin --';
$to_empty = 'Ar vaezienn "Da" n\'hall ket bezañ goullo !';
$html_images_warning = 'Evit ho surentez ne vez ket diskwelet ar skeudennoù a-bell.';
$html_images_display = 'Diskwel ar skeudennoù';
$html_smtp_error_no_conn = 'Ne c\'haller ket digeriñ ar c\'hevreadur SMTP';
$html_smtp_error_unexpected = 'Respont SMTP dic\'hortoz :';
$lang_could_not_connect = 'N\'eus ket bet gallet kevreañ ouzh ar servijer';
$lang_invalid_msg_num = 'Direizh eo niverenn ar gemennadenn';
$html_file_upload_attack = 'Un dagadenn a c\'hall bezañ diwar ar restr karget';
$html_invalid_email_address = 'Chomlec\'h postel direizh';
$html_invalid_msg_per_page = 'Direizh eo an niver a gemennadennoù dre bajenn';
$html_invalid_wrap_msg = 'Direizh eo ledander treujadur ar gemennadenn';
$html_seperate_msg_win = 'Kemennadennoù e prenestroù disrann';
$html_err_file_contacts = 'Ne c\'haller ket digeriñ restr an darempredoù evit skrivañ.';
$html_session_file_error = 'Ne c\'haller ket digeriñ restr an dalc\'hoù evit skrivañ.';
$html_login_not_allowed = 'N\'eo ket aotreet kevreañ gant an anv implijer-mañ.';
$lang_err_send_delay = 'Ret eo deoc\'h gortoz etre daou bostel (%1$d eilenn)';
$html_search = 'Klask';
